/* ---------------------------------------------------------------------------
 *
 * Project:	UT-SNMP
 *
 * Filename:	testfoid.c
 *
 * Date:	September 1994
 * 
 * Purpose:	Tester for Converter of Friendly-named Object Identifiers.
 *
 *			The program accepts a dotted OID at the prompt, both 
 *
 * 			names and numbers, e.g.:
 *
 *					1.3.dod.2
 *
 *			It will translate this, provided that the database
 *
 *			is consistent, into both a friendly name and an 
 * 
 *			ordinary OID.
 *
 * Auther(s):	Erwin Schrijver
 *
 * ---------------------------------------------------------------------------
 */

#include <ut-foid.h>

#define BUFSIZE	1000

/* ---------------------------------------------------------------------------
 *
 * Function:	main
 *
 * Arguments:	None
 *
 * Return:	STATUS, OK on success and FAILED otherwise.
 *
 * Purpose:	* Open database
 *		* Convert OID
 *		* Print result
 *		* Close database
 *
 * Remarks:	This routine tests the library libFOID.a
 *
 * ---------------------------------------------------------------------------
 */
	int 
main ( )
{
	FoidT	*pDataBase;
	char	szInvoer[ARG_LEN];	
	int	nDescription = 0;
	int	nError;
	AsnOcts	octOID;
	AsnOcts	octFriendly;
	AsnOcts	octDescription;
	
	if (foidOpen( &pDataBase ) == ERROR )
		exit ( FAILED );	
	
	octOID.octs = (char *) malloc( ARG_LEN );
	octOID.octetLen = ARG_LEN;
	strncpy( octOID.octs, EOL, 1 );
	
	octFriendly.octs = (char *) malloc( ARG_LEN );
	octFriendly.octetLen = ARG_LEN;	
	strncpy( octFriendly.octs, EOL, 1 );
	
	octDescription.octs = (char *) malloc( 1000 );
	octDescription.octetLen = 1000;
	strncpy( octDescription.octs, EOL, 1 );
	
	while ( 1 ){
		printf( "\nGive mixed OID ( q to stop, d to display description ):\n%%> " );
		scanf( "%s", szInvoer );
		printf( "\n" );
		if( (!strcmp( szInvoer, "q" )) && (strlen( szInvoer ) == 1))
			break;
		if( (!strcmp( szInvoer, "d" )) && (strlen( szInvoer ) == 1)){
			if ( nDescription == 0 ) continue;
			switch (foidDescription( nDescription, octDescription )){
				case OK:			
					break;
				case ERROR:
					foidClose( &pDataBase );
					free( octDescription.octs );
					free( octOID.octs );
					free( octFriendly.octs );
					exit ( FAILED );
				case FAILED:
					if (strlen( octDescription.octs ) == 0){
						fprintf( stderr, "Desciption not found\n" );
						continue;
					}
					else
						fprintf( stderr, "Warning : Buffer not large enough to contain description\n" );
					break;
			}
			printf( "****************************************\n\n" );
			printf( "Description of : %s\n\n", octFriendly.octs );
			printf( "%s\n", octDescription.octs );
			printf( "\n****************************************\n" );continue;
		}			
		switch (foidConv( pDataBase, szInvoer, 
				 octFriendly, octOID, &nDescription, &nError ) ){
			case ERROR:
				foidClose( &pDataBase );
				free( octDescription.octs );
				free( octOID.octs );
				free( octFriendly.octs );
				exit ( FAILED );
				
			case FAILED:
				if (nError == ILLEGAL)
					fprintf( stderr, "OID illegal\n" );
				else if (nError == NBUF)
					fprintf( stderr, "WARNING : Buffer not large enough to contain OID's\n" );
				else if (nError == NTOTAL)
					fprintf( stderr, "WARNING : OID not (entirely) found.\n" );
				break;
			case OK:
				break;
		}		
		printf( "****************************************\n\n" );printf( "Friendly-name : %s\n", octFriendly.octs );
		printf( "Normal OID    : %s\n", octOID.octs );
		if (nDescription > 0)
			printf( "Description available.\n" );
		else
			printf( "No Description.\n" );
		printf( "\n****************************************\n" );
	}
	
	foidClose( &pDataBase );
	free( octOID.octs );
	free( octFriendly.octs );
	free( octDescription.octs );		
	exit ( OK );
}

/* ---------------------------------------------------------------------------
 */
